@@ -1,8 +1,24 @@
+/* vim: set expandtab ts=8 sw=4: */
+
+/*  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
 #ifndef SCROLLBOX_H
 #define SCROLLBOX_H
 
-#include <gdk/gdk.h>
-#include <gtk/gtk.h>
+G_BEGIN_DECLS
 
 GType gtk_scrollbox_get_type (void);
 
@@ -28,14 +44,24 @@ struct _GtkScrollbox {
         gint draw_timeout;
 
         GdkPixmap *pixmap;
-
-        
 };
+
 struct _GtkScrollboxClass {
         GtkDrawingAreaClass parent;
 };
-void gtk_scrollbox_set_label(GtkScrollbox *self, gint n, gchar *value);
-GtkWidget* gtk_scrollbox_new (void);
-void gtk_scrollbox_enablecb (GtkScrollbox *self, gboolean enable);
-void gtk_scrollbox_clear (GtkScrollbox *self);
+
+void
+gtk_scrollbox_set_label (GtkScrollbox *self, gint n, gchar *value);
+
+GtkWidget *
+gtk_scrollbox_new       (void);
+
+void
+gtk_scrollbox_enablecb  (GtkScrollbox *self, gboolean enable);
+
+void
+gtk_scrollbox_clear     (GtkScrollbox *self);
+
+G_END_DECLS
+
 #endif
